@@ -6,12 +6,10 @@ import importlib
 import argparse
 from typing import Optional, Dict, List
 from datetime import datetime
-from pdb import set_trace
 
 import ray
 from ray import tune
 
-from hpogrid.components import validation
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper
     
@@ -51,19 +49,26 @@ class JobBuilder():
         self._mode = value
         
     @property
-    def resource(self):
-        return self._resource
+    def resource_per_trial(self):
+        return self._resource_per_trial
     
-    @resource.setter
-    def resource(self, value):
+    @resource_per_trial.setter
+    def resource_per_trial(self, value):
         resource = JobBuilder.get_resource_info()
+        resource_per_trial = {}
+        for device in ['cpu', 'gpu']:
+            if resource[device] >= self.max_concurrent:
+                resource_per_trial[device] = int(resource[device]/self.max_concurrent)  
+            else:
+                resource_per_trial[device] = 0
+        max_concurrent = self.max_concurrent
         if isinstance(value, dict):
             for device in ['cpu', 'gpu']:
                 if device in value and value[device]:
-                    resource[device] = min(value[device], resource[device])
-        print('INFO: Each trial will use {} GPU(s) resource'.format(resource['gpu']))
-        print('INFO: Each trial will use {} CPU(s) resource'.format(resource['cpu']))
-        self._resource = resource
+                    resource_per_trial[device] = min(value[device], resource_per_trial[device])
+        print('INFO: Each trial will use {} GPU(s) resource'.format(resource_per_trial['gpu']))
+        print('INFO: Each trial will use {} CPU(s) resource'.format(resource_per_trial['cpu']))
+        self._resource_per_trial = resource_per_trial
 
         
     @property
@@ -125,6 +130,7 @@ class JobBuilder():
         self._hyperparameters = {}
         self._start_timestamp = None
         self.idds_job = False
+        self.scripts_path = os.getcwd()
 
         
     @staticmethod
@@ -196,15 +202,19 @@ class JobBuilder():
         return algorithm
 
     @staticmethod
-    def get_model(script_name, model_name):
+    def get_model(script_name, model_name, scripts_path=None):
+        scripts_path = os.getcwd() if scripts_path is None else scripts_path
         model = None
         script_name_noext = os.path.splitext(script_name)[0]
         try: 
+            helper.set_scripts_path(scripts_path)
             module = importlib.import_module(script_name_noext)
             model = getattr(module, model_name)
         except: 
             raise ImportError('Unable to import function/class {} '
                 'from training script: {}.py'.format(model_name, script_name_noext))
+        finally:
+            helper.set_scripts_path(scripts_path, undo=True)
         return model
 
     def create_metadata(self, df) -> Dict:
@@ -253,7 +263,9 @@ class JobBuilder():
         return resource
     
     def run(self) -> None:
-        
+        if not helper.is_grid_job_running():
+            helper.local_setup()
+            
         self._start_timestamp = start = time.time()
 
         if self.algorithm == 'tune':
@@ -279,7 +291,7 @@ class JobBuilder():
             self.search_space,
             **self.scheduler_param)
 
-        model = JobBuilder.get_model(self.model_script, self.model_name)
+        model = JobBuilder.get_model(self.model_script, self.model_name, self.scripts_path)
 
         self._start_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
 
@@ -298,7 +310,7 @@ class JobBuilder():
                 search_alg=algorithm,
                 config=tune_config_space,
                 num_samples=self.num_trials,
-                resources_per_trial=self.resource,
+                resources_per_trial=self.resource_per_trial,
                 verbose=self.verbose,
                 local_dir=self.log_dir,
                 stop=self.stop,
@@ -336,8 +348,7 @@ class JobBuilder():
     def from_project(cls, proj_name:str, idds_job=False):
         
         config = helper.get_project_config(proj_name)
-        
-        helper.set_script_path(proj_name)
+        scripts_path = helper.get_scripts_path(proj_name)
         
         if idds_job:
             workdir = helper.get_workdir()
@@ -346,59 +357,17 @@ class JobBuilder():
                 input_point = json.load(input_point_file)
             return JobBuilder.from_config_for_idds(config, input_point)
         
-        return JobBuilder.from_config(config)
+        return JobBuilder.from_config(config, scripts_path=scripts_path)
     
     
     
     @classmethod
-    def from_json(cls, fname:str):
-        with open(fname, 'r') as config_file:
-            config = json.load(config_file)       
-        return JobBuilder.from_config(config)
-    
-    @classmethod
-    def from_config_for_idds(cls, config:Dict, input_point:Dict):
+    def from_config(cls, config_input: [Dict, str], scripts_path=None):
+        config = helper.load_configuration(config_input)
+        
         job = JobBuilder()
-        
-        job.project_name = config['project_name']
-        
-        # Load search space
-        job.search_space = {}
-        
-        # Load hpo configuration
-        job.algorithm = 'random'
-        job.metric = config['hpo_config']['metric']
-        job.mode = config['hpo_config']['mode']
-        job.scheduler = None
-        job.scheduler_param = {}
-        job.algorithm_param = {}
-        job.num_trials = 1
-        job.max_concurrent = 1
-        job.verbose = False
-        job.log_dir = config['hpo_config']['log_dir']
-        job.stop = config['hpo_config']['stop']
-        
-        # Load model configuration
-        job.model_script = config['model_config']['script']
-        job.model_name = config['model_config']['model']
-        job.model_param = config['model_config']['param']
-        
-        if set(input_point.keys()) != set(config['search_space'].keys()):
-            raise ValueError('hyperparameters given by input search point '
-                             'are inconsistent with search space definition')
-        
-        job.model_param.update(input_point)
-        job._hyperparameters = list(input_point.keys())
-        job.idds_job = True
-    
-        return job
-       
-    
-    @classmethod
-    def from_config(cls, config:Dict):
-        job = JobBuilder()
-        
         job.project_name = config['project_name']
+        job.scripts_path = config['scripts_path'] if scripts_path is None else scripts_path
         
         # Load search space
         job.search_space = config['search_space']
@@ -414,8 +383,8 @@ class JobBuilder():
         job.max_concurrent = config['hpo_config']['max_concurrent']
         job.verbose = config['hpo_config']['verbose']
         job.log_dir = config['hpo_config']['log_dir']
-        job.stop = config['hpo_config']['stop']
-        job.resource = config['hpo_config']['resource']
+        job.stop = config['hpo_config'].get('stop', None)
+        job.resource_per_trial = config['hpo_config'].get('resource', None)
         
         # Load model configuration
         job.model_script = config['model_config']['script']
@@ -425,7 +394,45 @@ class JobBuilder():
         job._hyperparameters = list(job.search_space.keys())
     
         return job
-       
+    
+    @classmethod
+    def from_config_for_idds(cls, config:Dict, input_point:Dict):
+        job = JobBuilder()
+
+        job.project_name = config['project_name']
+        job.scripts_path = config['scripts_path']
+
+        # Load search space
+        job.search_space = {}
+
+        # Load hpo configuration
+        job.algorithm = 'random'
+        job.metric = config['hpo_config']['metric']
+        job.mode = config['hpo_config']['mode']
+        job.scheduler = None
+        job.scheduler_param = {}
+        job.algorithm_param = {}
+        job.num_trials = 1
+        job.max_concurrent = 1
+        job.verbose = False
+        job.log_dir = config['hpo_config']['log_dir']
+        job.stop = config['hpo_config']['stop']
+
+        # Load model configuration
+        job.model_script = config['model_config']['script']
+        job.model_name = config['model_config']['model']
+        job.model_param = config['model_config']['param']
+
+        if set(input_point.keys()) != set(config['search_space'].keys()):
+            raise ValueError('hyperparameters given by input search point '
+                             'are inconsistent with search space definition')
+
+        job.model_param.update(input_point)
+        job._hyperparameters = list(input_point.keys())
+        job.idds_job = True
+
+        return job
+     
 def local_job_parser(idds_job=False):
     parser = argparse.ArgumentParser(description='run hyperparameter optimization '
                                     'for a user defined machine learning project')     
@@ -433,7 +440,6 @@ def local_job_parser(idds_job=False):
                         'hyperparameter optimization is run')    
     args = parser.parse_args(sys.argv[2:])
     
-    helper.local_setup()
     job = JobBuilder.from_project(args.proj_name, idds_job=idds_job)
     job.run()
             
@@ -447,5 +453,12 @@ def grid_job_parser(idds_job=False):
     finally:
         helper.remove_files(extracted_files)
             
-    
 
+if __name__ == '__main__':
+    parser = argparse.ArgumentParser(description='Run hyperparameter optimization '
+                                    'from a configuration file')     
+    parser.add_argument('config_file', help='Name of configuration file in either '
+                        'json or yaml format')    
+    config_file = parser.parse_args().config_file
+    job = JobBuilder.from_config(config_file)
+    job.run()
