@@ -168,6 +168,5 @@ class ConfigurationBase():
 
     def show(self, name):
         config = self.load_config(name)
-        formatted_str = stylus.create_table(config, self.show_columns, indexed=False,
-                                           wrap_nested_dict=True)
-        print(formatted_str)
+        table = stylus.create_table(config.items(), self.show_columns, indexed=False)
+        print(table)
