@@ -146,66 +146,6 @@ class ProjectConfiguration(ConfigurationBase):
             json.dump(search_space, idds_search_space_file)
             print('INFO: Created iDDS search space file: {}'.format(idds_search_space_path))
             
-        '''
-        # save configurations for idds workflow
-        idds_config_path = os.path.join(idds_dir, kiDDSConfigName)
-        idds_config = self.to_idds_config(project_config)
-        with open(idds_config_path, 'w') as idds_config_file:
-            json.dump(idds_config, idds_config_file, indent=2)
-            print('INFO: Created iDDS configuration: {}'.format(idds_config_path))
-        '''
-        '''
-        for key in kConfigList:
-            if (key in config) and (config[key] is not None):
-                dest = os.path.join(config_dir, '{}.json'.format(key))
-                shutil.copy2(config[key], dest)
-                print('INFO: Copied {} to {}'.format(config[key], dest))
-        project_config = {}
-        project_config_path = os.path.join(config_dir, kProjectConfigName)
-        if os.path.exists(project_config_path):
-            project_config = json.load(open(project_config_path))
-        
-        project_config = {**self.project_config, **project_config}
-        with open(project_config_path,'w') as proj_config_file:
-            json.dump(project_config, proj_config_file, indent=2)
-        '''
-    
-    '''
-    # subject to updates
-    @staticmethod
-    def to_idds_config(config):
-        project_name = config['project_name']
-        evaluation_container = config['grid_config']['container']
-        library = config['hpo_config']['algorithm']
-        method = config['hpo_config']['algorithm_param'].get('method', None)
-        in_ds = config['grid_config']['inDS']
-        max_concurrent = config['hpo_config']['max_concurrent']
-        max_point = config['hpo_config']['num_trials']
-        idds_config = {}
-        generator_options = {}
-        generator_options['n_point'] = '%NUM_POINTS'
-        generator_options['max_point'] = '%MAX_POINTS'
-        generator_options['infile'] = os.path.join(kWorkDir, '%IN')
-        generator_options['outfile'] = os.path.join(kWorkDir, '%OUT')
-        generator_options['library'] = library
-        if method:
-            generator_options['method'] = method
-        generator_cmd = 'hpogrid generate ' + stylus.join_options(generator_options)
-        
-        idds_config['steeringExec'] = ('run --rm -v \"$(pwd)\":{workdir} {container} '
-        '/bin/bash -c \"{cmd}\"').format(workdir=kWorkDir, container=kDefaultContainer, cmd=generator_cmd)
-        idds_config['evaluationExec'] = 'hpogrid idds_run {project_name}'.format(project_name=project_name)
-        idds_config['evaluationContainer'] = evaluation_container
-        idds_config['evaluationInput'] = kiDDSHPinput
-        idds_config['evaluationOutput'] = kiDDSHPoutput
-        idds_config['evaluationMeta'] = kGridSiteMetadataFileName
-        idds_config['nParallelEvaluation'] = max_concurrent
-        idds_config['maxPoints'] = max_point
-        idds_config['trainingDS'] = in_ds        
-
-        return idds_config
-    '''
-    
     def get_config_list(self, expr=None):
         project_list = [ s for s in super().get_config_list() if s is not 'backup']
         return project_list
