@@ -10,7 +10,7 @@ import multiprocessing
 from typing import List, Dict
 from contextlib import contextmanager
 
-from hpogrid.components.defaults import *
+from hpogrid.components.defaults import *  
 
 class NpEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -54,17 +54,19 @@ def get_base_path():
         self.set_base_path(os.getcwd())
     return os.environ.get(kHPOGridEnvPath, os.getcwd())
 
-def set_script_path(proj_name, undo=False):
-    project_path = get_project_path(proj_name)
-    script_path = os.path.join(project_path, 'scripts')
-    
-    if (script_path in sys.path) and (undo==True):
-        sys.path.remove(script_path)
-        os.environ["PYTHONPATH"].replace(script_path+":","")
+def set_scripts_path(scripts_path, undo=False):
+    if (scripts_path in sys.path) and (undo==True):
+        sys.path.remove(scripts_path)
+        os.environ["PYTHONPATH"].replace(scripts_path+":","")
         
-    if (script_path not in sys.path) and (undo==False):
-        sys.path.append(script_path)
-        os.environ["PYTHONPATH"] = script_path + ":" + os.environ.get("PYTHONPATH", "")
+    if (scripts_path not in sys.path) and (undo==False):
+        sys.path.append(scripts_path)
+        os.environ["PYTHONPATH"] = scripts_path + ":" + os.environ.get("PYTHONPATH", "")
+
+def set_scripts_path_from_project(proj_name, undo=False):
+    project_path = get_project_path(proj_name)
+    scripts_path = os.path.join(project_path, 'scripts')
+    set_scripts_path(scripts_path, undo=undo)
 
 def get_project_path(proj_name):
     if is_grid_job_running():
@@ -76,6 +78,11 @@ def get_project_path(proj_name):
         raise RuntimeError('Project "{}" not found.'.format(proj_name))
     return proj_path
 
+def get_scripts_path(proj_name):
+    project_path = get_project_path(proj_name)
+    scripts_path = os.path.join(project_path, 'scripts')
+    return scripts_path
+
 def load_configuration(config_input:[Dict, str]) -> Dict:
     if isinstance(config_input, dict):
         return config_input
